@@ -3,7 +3,7 @@ package Shipwright::Backend::FS;
 use warnings;
 use strict;
 use Carp;
-use File::Spec;
+use File::Spec::Functions qw/catfile catdir/;
 use Shipwright::Util;
 use File::Copy qw/copy/;
 use File::Copy::Recursive qw/dircopy/;
@@ -111,7 +111,7 @@ sub _yml {
     my $path = shift;
     my $yml  = shift;
 
-    my $file = File::Spec->catfile( $self->repository, $path );
+    my $file = catfile( $self->repository, $path );
     if ($yml) {
 
         Shipwright::Util::DumpFile( $file, $yml );
@@ -158,11 +158,21 @@ sub _update_file {
     my $path   = shift;
     my $latest = shift;
 
-    my $file = File::Spec->catfile( $self->repository, $path );
+    my $file = catfile( $self->repository, $path );
 
     copy( $latest, $file );
 }
 
+=item import
+
+=cut
+
+sub import {
+    my $self = shift;
+    return unless @_;
+    return $self->SUPER::import( @_, delete => 1 );
+}
+
 =back
 
 =cut
